@@ -36,6 +36,7 @@ use Froxlor\PhpHelper;
 use Froxlor\Settings;
 use Froxlor\System\Cronjob;
 use Froxlor\System\IPTools;
+use Froxlor\UI\Request;
 use Froxlor\Validate\Validate;
 use PDO;
 
@@ -124,25 +125,20 @@ class Store
 		}
 
 		if (count($ids) > 0) {
-			$defaultips_new = explode(',', $newfieldvalue);
 
-			if (!empty($defaultips_old) && !empty($newfieldvalue)) {
-				$in_value = $defaultips_old . ", " . $newfieldvalue;
-			} elseif (!empty($defaultips_old) && empty($newfieldvalue)) {
-				$in_value = $defaultips_old;
-			} else {
-				$in_value = $newfieldvalue;
+			if (!empty($defaultips_old)) {
+				// Delete the existing mappings linking to default IPs
+				$del_stmt = Database::prepare("
+					DELETE FROM `" . TABLE_DOMAINTOIP . "`
+					WHERE `id_domain` IN (" . implode(', ', $ids) . ")
+					AND `id_ipandports` IN (" . $defaultips_old . ")
+				");
+				Database::pexecute($del_stmt);
 			}
 
-			// Delete the existing mappings linking to default IPs
-			$del_stmt = Database::prepare("
-				DELETE FROM `" . TABLE_DOMAINTOIP . "`
-				WHERE `id_domain` IN (" . implode(', ', $ids) . ")
-				AND `id_ipandports` IN (" . $in_value . ")
-			");
-			Database::pexecute($del_stmt);
-
+			$defaultips_new = !empty($newfieldvalue) ? explode(",", $newfieldvalue) : [];
 			if (count($defaultips_new) > 0) {
+
 				// Insert the new mappings
 				$ins_stmt = Database::prepare("
 					INSERT INTO `" . TABLE_DOMAINTOIP . "`
@@ -165,6 +161,9 @@ class Store
 	{
 		$defaultips_old = Settings::Get('system.defaultsslip');
 
+		self::cleanIpSelection($defaultips_old);
+		self::cleanIpSelection($newfieldvalue);
+
 		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
 
 		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && $fielddata['varname'] == 'defaultsslip') {
@@ -174,6 +173,14 @@ class Store
 		return $returnvalue;
 	}
 
+	private static function cleanIpSelection(&$selection)
+	{
+		$selection_arr = array_filter(explode(',', $selection), function ($value) {
+			return !empty($value);
+		});
+		$selection = implode(",", $selection_arr);
+	}
+
 	/**
 	 * updates the setting for the default panel-theme
 	 * and also the user themes (customers and admins) if
@@ -225,6 +232,28 @@ class Store
 		return $returnvalue;
 	}
 
+	public static function storeSettingFieldInsertAntispamTask($fieldname, $fielddata, $newfieldvalue)
+	{
+		// first save the setting itself
+		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
+
+		if ($returnvalue !== false) {
+			Cronjob::inserttask(TaskId::REBUILD_RSPAMD);
+		}
+		return $returnvalue;
+	}
+
+	public static function storeSettingFieldInsertUpdateServicesTask($fieldname, $fielddata, $newfieldvalue)
+	{
+		// first save the setting itself
+		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
+
+		if ($returnvalue !== false) {
+			Cronjob::inserttask(TaskId::UPDATE_LE_SERVICES);
+		}
+		return $returnvalue;
+	}
+
 	public static function storeSettingHostname($fieldname, $fielddata, $newfieldvalue)
 	{
 		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
@@ -454,7 +483,7 @@ class Store
 			}
 
 			// Delete file?
-			if ($fielddata['value'] !== "" && array_key_exists($fieldname . '_delete', $_POST) && $_POST[$fieldname . '_delete']) {
+			if ($fielddata['value'] !== "" && array_key_exists($fieldname . '_delete', $_POST) && Request::post($fieldname . '_delete')) {
 				@unlink(Froxlor::getInstallDir() . '/' . explode('?', $fielddata['value'], 2)[0]);
 				$save_to = '';
 			}
